namespace efl { namespace ui { 
inline ::efl::eolian::return_traits<int>::type Nstate::count_get() const
{
   int __return_value =  ::efl_ui_nstate_count_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<int>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Nstate::count_set( ::efl::eolian::in_traits<int>::type nstate) const
{
    ::efl_ui_nstate_count_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(nstate));
}
inline ::efl::eolian::return_traits<int>::type Nstate::value_get() const
{
   int __return_value =  ::efl_ui_nstate_value_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<int>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Nstate::value_set( ::efl::eolian::in_traits<int>::type state) const
{
    ::efl_ui_nstate_value_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(state));
}
#ifdef EFL_UI_NSTATE_CLASS_PROTECTED
inline ::efl::eolian::return_traits<void>::type Nstate::activate() const
{
    ::efl_ui_nstate_activate(this->_eo_ptr());
}
#endif
} } 
namespace eo_cxx {
namespace efl { namespace ui { 
inline ::efl::eolian::return_traits<int>::type Nstate::count_get() const
{
   int __return_value =  ::efl_ui_nstate_count_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<int>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Nstate::count_set( ::efl::eolian::in_traits<int>::type nstate) const
{
    ::efl_ui_nstate_count_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(nstate));
}
inline ::efl::eolian::return_traits<int>::type Nstate::value_get() const
{
   int __return_value =  ::efl_ui_nstate_value_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<int>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Nstate::value_set( ::efl::eolian::in_traits<int>::type state) const
{
    ::efl_ui_nstate_value_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(state));
}
#ifdef EFL_UI_NSTATE_CLASS_PROTECTED
inline ::efl::eolian::return_traits<void>::type Nstate::activate() const
{
    ::efl_ui_nstate_activate(this->_eo_ptr());
}
#endif
inline efl::ui::Nstate::operator ::efl::ui::Nstate() const { return *static_cast< ::efl::ui::Nstate const*>(static_cast<void const*>(this)); }
inline efl::ui::Nstate::operator ::efl::ui::Nstate&() { return *static_cast< ::efl::ui::Nstate*>(static_cast<void*>(this)); }
inline efl::ui::Nstate::operator ::efl::ui::Nstate const&() const { return *static_cast< ::efl::ui::Nstate const*>(static_cast<void const*>(this)); }
} } }

